/*global define,window*/
define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'testsuite/qunit-fixture!de_epages/ipayment/ui/ipaymentguirefresh-test',
    'de_epages/ipayment/ui/ipaymentguirefresh'
], function(QUnit, $, ep, fixture, ipaymentguirefresh) {

    'use strict';
    QUnit.module('de_epages/ipayment/ui/ipaymentguirefresh', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.test('Test when payment method has no 3dSecure and auth Transaction Type', 2, function() {

        var SelectedPaymentMethodId = '18361';
        var PaymentTypeMethodsData = {
            "PaymentMethodTable": [{
                "Options3dSecure": ["0"],
                "TransactionTypes": ["auth"],
                "PaymentMethodID": "18361"
            }]
        };
        var threedDivSection = $('#' + 'Mode3dSecureForm');
        var PaymentTypeDivSection = $('#' + 'AuthPreauthSwitch');
        var SelectedTransactionType = $('#' + 'SelectedTransactionTypeid');
        var Selected3dSecureOption = $('#' + 'Selected3dSecureModeid');


        ipaymentguirefresh(SelectedPaymentMethodId, PaymentTypeMethodsData, threedDivSection, PaymentTypeDivSection, SelectedTransactionType, Selected3dSecureOption);


        QUnit.strictEqual(
            SelectedTransactionType.val(),
            'auth',
            'The value of SelectedTransactionType is the same than was in the JSON Data. We expect have the value auth'
        );
        QUnit.strictEqual(
            threedDivSection.is(":visible"),
            false,
            'The 3dSecure Div section has to be hidden. We expect the threedDivSection with the attribute visible to false'
        );
    });

    QUnit.test('Test when payment method has 3dSecure and preauth Transaction Type', 2, function() {

        var SelectedPaymentMethodId = '18353';
        var PaymentTypeMethodsData = {
            "PaymentMethodTable": [{
                "Options3dSecure": ["1", "0"],
                "TransactionTypes": ["preauth"],
                "PaymentMethodID": "18353"
            }]
        };
        var threedDivSection = $('#' + 'Mode3dSecureForm');
        var PaymentTypeDivSection = $('#' + 'AuthPreauthSwitch');
        var SelectedTransactionType = $('#' + 'SelectedTransactionTypeid');
        var Selected3dSecureOption = $('#' + 'Selected3dSecureModeid');


        ipaymentguirefresh(SelectedPaymentMethodId, PaymentTypeMethodsData, threedDivSection, PaymentTypeDivSection, SelectedTransactionType, Selected3dSecureOption);


        QUnit.strictEqual(
            SelectedTransactionType.val(),
            'preauth',
            'The value of SelectedTransactionType is the same than was in the JSON Data. We expect have the value preauth'
        );
        QUnit.strictEqual(
            threedDivSection.is(":visible"),
            true,
            'The 3dSecure Div section has to be Shown. We expect the threedDivSection with the attribute visible to true'
        );
    });

    QUnit.test('Test when payment method has no 3dSecure and both Transaction Type', 3, function() {

        var SelectedPaymentMethodId = '18353';
        var PaymentTypeMethodsData = {
            "PaymentMethodTable": [{
                "Options3dSecure": ["0"],
                "TransactionTypes": ["auth", "preauth"],
                "PaymentMethodID": "18353"
            }]
        };
        var threedDivSection = $('#' + 'Mode3dSecureForm');
        var PaymentTypeDivSection = $('#' + 'AuthPreauthSwitch');
        var SelectedTransactionType = $('#' + 'SelectedTransactionTypeid');
        var Selected3dSecureOption = $('#' + 'Selected3dSecureModeid');


        ipaymentguirefresh(SelectedPaymentMethodId, PaymentTypeMethodsData, threedDivSection, PaymentTypeDivSection, SelectedTransactionType, Selected3dSecureOption);

        QUnit.strictEqual(
            $('#SelectedTransactionTypeid option').size(),
            2,
            'The number of options in SelectedTransactionType are 2. We expect have a Select element of the DOM with 2 elements'
        );
        QUnit.strictEqual(
            PaymentTypeDivSection.is(":visible"),
            true,
            'The PaymentTypeDivSection  Div has to be Shown. We expect have the attribute visible to true'
        );
        QUnit.strictEqual(
            threedDivSection.is(":visible"),
            false,
            'The 3dSecure Div section has not to be Shown. We expect the threedDivSection with the attribute visible to false'
        );
    });


    QUnit.test('Test when payment method has 3dSecure and both Transaction Type', 3, function() {

        var SelectedPaymentMethodId = '18357';

        var PaymentTypeMethodsData = {
            "PaymentMethodTable": [{
                "Options3dSecure": ["1", "0"],
                "TransactionTypes": ["auth", "preauth"],
                "PaymentMethodID": "18357"
            }]
        };
        var threedDivSection = $('#' + 'Mode3dSecureForm');
        var PaymentTypeDivSection = $('#' + 'AuthPreauthSwitch');
        var SelectedTransactionType = $('#' + 'SelectedTransactionTypeid');
        var Selected3dSecureOption = $('#' + 'Selected3dSecureModeid');


        ipaymentguirefresh(SelectedPaymentMethodId, PaymentTypeMethodsData, threedDivSection, PaymentTypeDivSection, SelectedTransactionType, Selected3dSecureOption);

        QUnit.strictEqual(
            $('#SelectedTransactionTypeid option').size(),
            2,
            'The number of options in SelectedTransactionType are 2. We expect have a Select element of the DOM with 2 elements'
        );
        QUnit.strictEqual(
            PaymentTypeDivSection.is(":visible"),
            true,
            'The PaymentTypeDivSection  Div has to be Shown. We expect have the attribute visible to true'
        );
        QUnit.strictEqual(
            threedDivSection.is(":visible"),
            true,
            'The 3dSecure Div section has to be Shown. We expect the threedDivSection with the attribute visible to true'
        );
    });
});
